Skip to main content Crate choice_string Copy item path Source Error Error type for errors that may arise during the parsing of choice-strings.
Very simple at the moment, only wrapping a nom ErrorKind Selection A parsed selection. Can represent all, none, or some set of ranges and items. SomeElementType A selected element. Can either be an individual item, or a range of items. parse Parse a choice string input to a Selection . Additionally reduces the set of ranges to the
minimum representable by using a union operation.
Wrapper for str::parse . parse_raw Parses a choice string to a Selection . This does not do any de-duplicating or condensing of
parsed ranges.