Selection

Enum Selection 

pub enum Selection {
    All,
    Some(Vec<SomeElementType>),
    None,
}
A parsed selection. Can represent all, none, or some set of ranges and items.

Variants



All

All elements are in the selected set



Some(Vec<SomeElementType>)

Some elements are in the selected set. The list of selections are in the Vec.



None

No elements are in the selected set

Implementations

Source

impl Selection

pub fn contains_item(&self, item: usize) -> bool

Check if the selection contains an item. Returns true if All, false if None, and checks included elements if Some.